#!/bin/bash

# Determine Operating System and set the BASE_PATH accordingly
OS_TYPE=$(uname)
if [ "$OS_TYPE" = "Darwin" ]; then
    BASE_PATH="/Library"
else
    BASE_PATH="/opt"
fi

# Source the library.sh file from the correct location
source "$BASE_PATH/Devin/sudo_utils/library.sh"

# Check if the script is run as root
if [ "$EUID" -ne 0 ]; then
    echo "Please run as root"
    exit 1
fi

# Check argument count
if [ "$#" -ne 2 ]; then
    echo "This script requires exactly two arguments."
    exit 1
fi

src="$1"
dest="$2"

# Check for path traversal in both paths
check_path_traversal "$src"
check_path_traversal "$dest"

# Check file extension for both files
[[ "$src" == *.fmp12 ]] || { echo "Source is not a .fmp12 file"; exit 1; }
[[ "$dest" == *.fmp12 ]] || { echo "Destination is not a .fmp12 file"; exit 1; }

# Overwrite the variables with the cleaned paths
src=$(echo "$src" | sed 's|^[^:]*:||')
dest=$(echo "$dest" | sed 's|^[^:]*:||')

# Check if paths start with specific prefixes
check_valid_path "$src" || { echo "Invalid source prefix"; exit 1; }
check_valid_path "$dest" || { echo "Invalid destination prefix"; exit 1; }

# Copy the file or directory
cp -a "$src" "$dest" 

#Useful to sleep 1 to ensure the following operations are ready for the change
sleep 1

echo "Operations completed successfully."
exit 0
