#!/bin/bash

# Check if exactly one argument is given
if [ "$#" -ne 1 ]; then
    echo "This script requires exactly one argument."
    exit 1
fi

# Check if the script is run as root
if [ "$EUID" -ne 0 ]; then
    echo "Please run as root" 
    exit 1
fi

action="$1"
OS_TYPE=$(uname)

# Define plist file location for macOS
PLIST_FILE="/Library/LaunchDaemons/com.devin.handler.plist"
# Extract the Label for use with launchctl commands
SERVICE_LABEL="com.devin.handler"

# Validate the argument and execute the action
case "$action" in
  start|stop|restart)
    if [ "$OS_TYPE" = "Linux" ]; then
        systemctl "$action" devin-handler || { echo "Operation failed"; exit 1; }
    elif [ "$OS_TYPE" = "Darwin" ]; then
        # For macOS, adjust the action for launchctl compatibility
        case "$action" in
          start)
            # Use bootstrap for starting the service
            launchctl bootstrap system "$PLIST_FILE" || { echo "Operation failed"; exit 1; }
            ;;
          stop)
            # Use bootout for stopping the service
            launchctl bootout system "$PLIST_FILE" || { echo "Operation failed"; exit 1; }
            ;;
          restart)
            # Attempt to restart the service using kickstart
            launchctl bootout system "$PLIST_FILE" # Don't care if this fails, if its somehow not running then it doesn't matter if we try to stop it
            sleep 1
            launchctl bootstrap system "$PLIST_FILE" || { echo "Operation failed"; exit 1; }
            ;;
        esac
    else
        echo "Unsupported operating system."
        exit 1
    fi
    ;;
  *)
    echo "Invalid argument. Accepted values are start, stop, or restart."
    exit 1
    ;;
esac

echo "Operation $action completed successfully."
