#!/bin/bash

# Copyright © 2021-2022 Devin (protabase)
# DEVIN uninstaller
# VERSION 1.0.0
version="1.0.0"
# Colors :)
RED='\033[0;31m'
GREEN='\033[0;32m'
YELLOW='\033[1;33m'
BLUE='\033[0;34m'
NC='\033[0m' # No Color
# Like so: echo -e "I ${RED}love${NC} Stack Overflow"

#Color print function

# Echo function
# Echo function
color_echo() {
    local color=$1
    local msg=$2
    local color_value=""
    local info_box=""

    case $color in
        "ERROR")
            color_value=$RED
            info_box="[-]"
            ;;
        "SUCCESS")
            color_value=$GREEN
            info_box="[+]"
            ;;
        "INFO")
            color_value=$YELLOW
            info_box="[*]"
            ;;
        "QUESTION")
            color_value=$BLUE
            info_box="[?]"
            ;;
        *)
            echo "Invalid color"
            return 1
    esac

    echo -e "${color_value}${info_box} ${msg}${NC}" | tee -a $log_file
}

usage() {
    echo "Usage: $0 --username USERNAME --password PASSWORD -y"
    exit 1
}

# Uninstall function
uninstall() {
        # Prompt for username if not set
    if [[ -z "$username" ]]; then
        color_echo "QUESTION" "Please enter your username for FileMaker Admin Console:"
        read username
    fi

    # Prompt for password if not set
    if [[ -z "$password" ]]; then
        color_echo "QUESTION" "Please enter your password for FileMaker Admin Console (will not be echoed):"
        read -s password
    fi

    # Check if its possible to run a random fmsadmin command, if statuscode == 0 then success and we can proceed.
    fmsadmin LIST FILES -u "$username" -p "$password" > /dev/null
    exit_status=$?
    if [[ $exit_status -ne 0 ]]; then
        color_echo "ERROR" "It was not possible to validate your admin account credentials, please try again."
        exit 1
    fi
    color_echo "SUCCESS" "Credentials verified, continuing."
    color_echo "INFO" "Uninstalling Devin."

    # Check if mac or linux
    OS=$(uname)
    if [[ "$OS" == "Linux" ]]; then
        # Stop the handler first lol
        service_name="devin-handler"
        
        if systemctl list-unit-files | grep -Fqw "$service_name"; then
            color_echo "INFO" "Stopping and disabling the handler service."
            sudo systemctl disable "$service_name"  
            sudo systemctl stop "$service_name" 
            service_file_path=$(systemctl show -p FragmentPath "$service_name" | cut -d= -f2)
            if [ -f "$service_file_path" ]; then
                rm "$service_file_path" 
                systemctl daemon-reload 
                systemctl reset-failed 
            fi
        fi
        color_echo "INFO" "Closing devin-engine.fmp12 and removing it."
        fmsadmin close devin-engine.fmp12 -u "$username" -p "$password" -f -y 
        rm -rf /opt/FileMaker/FileMaker\ Server/Data/Databases/devin-engine.fmp12 
        # remove the sudo entries in /etc/sudoers
        color_echo "INFO" "Removing sudo entries for devin."
        sed -i '/devin/d' /etc/sudoers 

        # remove devin from nginx
        if [ -f /opt/FileMaker/FileMaker\ Server/NginxServer/conf/devin.conf ]; then
            color_echo "INFO" "Removing devin from nginx."
            sed -i '/devin/d' /opt/FileMaker/FileMaker\ Server/NginxServer/conf/fms_nginx.conf 
            rm /opt/FileMaker/FileMaker\ Server/NginxServer/conf/devin.conf 
            fmsadmin restart httpserver -u "$username" -p "$password"  -f -y 
        fi
        color_echo "INFO" "Terminating all processes owned by devin."
        pkill -9 -u devin
        # remove the devin user
        color_echo "INFO" "Removing devin user."
        userdel -r devin 
        groupdel devin 
        rm -rf /opt/Devin 
        color_echo "SUCCESS" "Devin has been uninstalled."
        exit 1
    else
        # Stop the handler first lol
        PLIST_FILE="/Library/LaunchDaemons/com.devin.handler.plist"

        color_echo "INFO" "Removing Devin Handler service."

        # Check if the service plist exists
        if [ -f "$PLIST_FILE" ]; then
            # Unload the service to stop it and remove it from launchd
            launchctl unload "$PLIST_FILE" 
            
            # Remove the plist file
            rm "$PLIST_FILE" 
            
            color_echo "SUCCESS" "Devin Handler service has been removed."
        else
            color_echo "INFO" "Devin Handler service plist file does not exist, nothing to remove."
        fi
        color_echo "INFO" "Closing devin-engine.fmp12 and removing it."
        fmsadmin close devin-engine.fmp12 -u "$username" -p "$password" -f -y 
        rm -rf "/Library/FileMaker Server/Data/Databases/devin-engine.fmp12" 
        # remove the sudo entries in /etc/sudoers
        color_echo "INFO" "Removing sudo entries for devin."
        temp_file=$(mktemp)
        cp -a "/etc/sudoers" "$temp_file"
        sudo sed -i '' '/^devin ALL/d' "$temp_file"
        cp -a "$temp_file" "/etc/sudoers"

        # remove devin from apache
        if grep -q "devin" /Library/FileMaker\ Server/HTTPServer/conf/extra/httpd-ssl.conf; then
            color_echo "INFO" "Removing devin from apache."
            sed -i '' '/devin/d' /Library/FileMaker\ Server/HTTPServer/conf/extra/httpd-ssl.conf 
            fmsadmin restart httpserver -u "$username" -p "$password"  -f -y 
        fi
        # remove the devin user
        color_echo "INFO" "Removing devin user."
        # Check if Devin user was a member of the fmsadmin group
        if dscl . -read /Groups/fmsadmin GroupMembership | grep -q "devin"; then
            # Remove Devin from the fmsadmin group
            dseditgroup -o edit -d devin -t user fmsadmin 
            color_echo "INFO" "Removed Devin user from fmsadmin group."
        fi

        # Then delete the Devin user
        sysadminctl -deleteUser devin -secure 

        rm -rf /Library/Devin 
        color_echo "SUCCESS" "Devin has been uninstalled."
        exit 0
    fi

    
}

# Check if script is ran as root
if [[ $EUID -ne 0 ]]; then
   color_echo "ERROR" "This script must be run as root." 
   exit 1
fi

# Lets remove :-)
color_echo "INFO" "Devin remover starting."

# Parse command-line arguments
while [[ $# -gt 0 ]]; do
    key="$1"

    case $key in
        --username)
            username="$2"
            shift # past argument
            shift # past value
            ;;
        --password)
            password="$2"
            shift # past argument
            shift # past value
            ;;
        -y)
            confirmed=true
            shift # past argument
            ;;
        *)    # unknown option
            usage
            ;;
    esac
done

# Check for correct amount of arguments and if any arguments are passed
if [[ -n $username && -n $password && $confirmed == true ]]; then
    # Proceed with uninstallation without confirmation
    uninstall
    exit 0
elif [[ -z $username || -z $password || $confirmed != true ]]; then
    if [[ $# -ne 0 ]]; then
        # Incorrect amount of arguments or incorrect usage
        usage
    fi
    # No arguments were passed, proceed with manual confirmation
    color_echo "QUESTION" "ARE YOU ABSOLUTELY SURE YOU WANT TO REMOVE DEVIN? THIS WILL DELETE THE /opt/Devin FOLDER, REMOVE ALL SERVICES AND THE DEVIN USER? TYPE (y) FOR YES OR (n) FOR NO."
    read answer

    case $answer in
        [Yy]* ) 
            uninstall
            exit 0
            ;;
        [Nn]* ) 
            color_echo "ERROR" "Exiting"
            exit 1;;
        * ) 
            color_echo "ERROR" "Please answer yes or no - Exiting"
            exit 1;;
    esac
else
    usage
fi