#!/bin/bash

# Determine Operating System
OS_TYPE=$(uname)
if [ "$OS_TYPE" = "Darwin" ]; then
    BASE_PATH="/Library"
else
    BASE_PATH="/opt"
fi

export PATH="$PATH:/usr/local/bin:/usr/bin:/bin:/usr/sbin:/sbin:/opt/bin" #Sometimes path is not set correctly so we just add some dupes here
# Check if the file_path is inside a valid folder
check_valid_path() {
    file_path="$1"
    existing_paths=("$BASE_PATH/Devin/" "/tmp/")
    OS_TYPE=$(uname)
    if [ "$OS_TYPE" = "Darwin" ]; then
        existing_paths+=("/Library/FileMaker Server/Data/Databases/")
        existing_paths+=("/Library/FileMaker Server/Data/Secure/")
    else
        existing_paths+=("/opt/FileMaker/FileMaker Server/Data/Databases/")
        existing_paths+=("/opt/FileMaker/FileMaker Server/Data/Secure/")
    fi

    additional_paths=()

    strip_macos_path() {
        local path="$1"
        echo "$path" | sed -E 's|filemac:/[^/]*/||'
    }
    strip_linux_path() {
        local path="$1"
        echo "$path" | sed 's|^[^:]*:||'
    }

    # Integrate OS check for additional paths
    if [ "$OS_TYPE" = "Darwin" ]; then
        # For macOS, adjust the path prefix within the jq command
        while IFS= read -r line; do
            if [[ "$line" != "disabled" ]]; then
                echo "Adding the line $line"
                stripped_path=$(strip_macos_path "$line")
                additional_paths+=("/$stripped_path")
            fi
        done < <(/usr/local/bin/jq -r '.additionalDatabaseFolder[], .additionalDatabaseFolder2[], .defaultDatabaseFolder, .secureDatabaseFolder | select(startswith("filemac:"))' /Library/Devin/sudo_utils/sudo_utils.json)
    else
        # For Linux, keep the original behavior
        while IFS= read -r line; do
            if [[ "$line" != "disabled" ]]; then
                stripped_path=$(strip_linux_path "$line")
                additional_paths+=("$stripped_path")
            fi
        done < <(/usr/bin/jq -r '.additionalDatabaseFolder[], .additionalDatabaseFolder2[], .defaultDatabaseFolder, .secureDatabaseFolder | select(startswith("filelinux:"))' /opt/Devin/sudo_utils/sudo_utils.json)
    fi

    # Append additional_paths to existing_paths
    existing_paths+=("${additional_paths[@]}")

    for valid_path in "${existing_paths[@]}"; do
        echo "Checking $file_path against $valid_path"
        if [[ "$file_path" == "$valid_path"* ]]; then
            return 0
        fi
    done
    return 1
}

check_path_traversal() {
    local input_path="$1"
    # Check if "../" is present in the path
    if [[ "$input_path" == *"../"* ]]; then
        echo "Path traversal detected: $input_path"
        exit 1
    else
        echo "Path is valid."
    fi
}
