#!/bin/bash

# Determine Operating System and set the BASE_PATH accordingly
OS_TYPE=$(uname)
if [ "$OS_TYPE" = "Darwin" ]; then
    BASE_PATH="/Library"
else
    BASE_PATH="/opt"
fi

# Source the library.sh file from the correct location
source "$BASE_PATH/Devin/sudo_utils/library.sh"

# Check if the script is run as root
if [ "$EUID" -ne 0 ]; then
    echo "Please run as root"
    exit 1
fi

# Check argument count
if [ "$#" -ne 1 ]; then
    echo "This script requires exactly one argument."
    exit 1
fi

target="$1"

# Check for path traversal in the path
check_path_traversal "$target"

# Check file extension for the target file
[[ "$target" == *.fmp12 ]] || { echo "Target is not a .fmp12 file"; exit 1; }

# Overwrite the variable with the cleaned path
target=$(echo "$target" | sed 's|^[^:]*:||')

# Check if path starts with specific prefixes
if check_valid_path "$target"; then
    rm -r "$target" || { echo "Remove operation failed"; exit 1; }
else
    echo "Invalid path prefix."
    exit 1
fi

echo "Operation completed successfully."
exit 0