#!/bin/bash

# Determine Operating System and set the BASE_PATH accordingly
OS_TYPE=$(uname)
if [ "$OS_TYPE" = "Darwin" ]; then
    BASE_PATH="/Library"
else
    BASE_PATH="/opt"
fi

# Source the library.sh file from the correct location
source "$BASE_PATH/Devin/sudo_utils/library.sh"

# Check if the script is run as root
if [ "$EUID" -ne 0 ]; then
    echo "Please run as root"
    exit 1
fi

# Check for a single argument
if [ "$#" -ne 1 ]; then
    echo "This script requires exactly one argument."
    exit 1
fi

file_path="$1"

# Check for path traversal
check_path_traversal "$file_path"

[[ "$file_path" == *.fmp12 ]] || { echo "Source is not a .fmp12 file"; exit 1; }

# Verify the argument's prefix
if check_valid_path "$file_path"; then
    chmod 755 "$file_path" || { echo "Chmod operation failed"; exit 1; }
    chown fmserver:fmsadmin "$file_path" || { echo "Chown operation failed"; exit 1; }
    echo "Operations completed successfully."
    exit 0
else
    echo "Invalid path prefix."
    exit 1
fi

