#!/bin/bash
# Determine Operating System and set the BASE_PATH accordingly
OS_TYPE=$(uname)
if [ "$OS_TYPE" = "Darwin" ]; then
    BASE_PATH="/Library"
else
    BASE_PATH="/opt"
fi

# Source the library.sh file from the correct location
source "$BASE_PATH/Devin/sudo_utils/library.sh"
# Define the URL and target directory
URL="https://download.devin.fm/downloads/server/latest/sudo_utils.zip"
TARGET_DIR="$BASE_PATH/Devin/sudo_utils/"

# Create the target directory if it doesn't exist
mkdir -p "$TARGET_DIR"

# Download the zip file to a temporary location
TEMP_ZIP=$(mktemp)
curl -o "$TEMP_ZIP" "$URL" || { echo "Download failed"; exit 1; }

# Unzip to the target directory
unzip -o "$TEMP_ZIP" -d "$TARGET_DIR" || { echo "Unzip failed"; exit 1; }

# Set executable permissions on all files in the target directory
find "$BASE_PATH/Devin/sudo_utils" -type f -exec chmod 755 {} + || { echo "Chmod failed"; exit 1; }

# Remove the temporary zip file
rm -f "$TEMP_ZIP"

echo "Helper scripts successfully downloaded, unzipped, and set as executable."
exit 0
