#!/bin/bash

# Determine Operating System and set the BASE_PATH accordingly
OS_TYPE=$(uname)
if [ "$OS_TYPE" = "Darwin" ]; then
    BASE_PATH="/Library"
else
    BASE_PATH="/opt"
fi

# Ensure only two parameters are passed, username and password
if [ "$#" -ne 2 ]; then
    echo "Illegal number of parameters"
    exit 1
fi

# Check its run as root
if [ "$EUID" -ne 0 ]; then
    echo "Please run as root"
    exit 1
fi

# Set the username and password
username=$1
password=$2

# 

token=$(curl -s -k -X POST "https://localhost/fmi/admin/api/v2/user/auth" -H "Content-Type: application/json" -H "Authorization: Basic $(echo -n "$username:$password" | base64)" | jq -r '.response.token')
if [ "$token" != "null" ] || [ -z "$token" ]; then
    # Check if the schedule somehow is there:
    database_paths=$(curl -s -k -X GET "https://localhost/fmi/admin/api/v2/server/currentfoldersettings" \
    -H "Content-Type: application/json" \
    -H "Authorization: Bearer $token")

    # Check if message.code is 0
    if echo "$database_paths" | jq '.messages[] | select(.code == "0")' >/dev/null; then
        # Extract the response dictionary and write it to sudo_utils.json
        echo "$database_paths" | jq '.response' > "$BASE_PATH/Devin/sudo_utils/sudo_utils.json"
        echo "The response has been extracted and written to sudo_utils.json."
    else
        echo "The code is not 0 or not found."
    fi
fi

curl -s -k -X DELETE "https://localhost/fmi/admin/api/v2/user/auth/$token" > /dev/null
